@@ -1,14 +1,16 @@
 package Hetula::Client;
 
-our $VERSION = '0.005';
+our $VERSION = '0.006';
 
 # ABSTRACT: Interface with Hetula
 #
 # Copyright 2018 National Library of Finland
 
+=encoding utf8
+
 =head1 NAME
 
-Hetula::Client
+Hetula::Client - Perl client implementation to communicate with Hetula.
 
 =head1 DESCRIPTION
 
